@@ -1,5 +1,5 @@
 from . import __meta__
-from .builder import DocumentationOptions, OpenAPIBuilder
+from .builder import DocumentationOptions, OpenApiDocumentation
 from .decorators import add_documentation
 
 __version__ = __meta__.version
@@ -7,5 +7,5 @@ __version__ = __meta__.version
 __all__ = [
     "add_documentation",
     "DocumentationOptions",
-    "OpenAPIBuilder",
+    "OpenApiDocumentation",
 ]
